@@ -1,6 +1,6 @@
 "dataquality"
 
-__version__ = "v0.0.8"
+__version__ = "v0.0.9"
 
 import resource
 
@@ -23,6 +23,7 @@ from dataquality.core.log import (
 
 def configure() -> None:
     """Update your active config with new env variables.
+    Reset user token on configure and prompt new login.
 
     Available environment variables to update:
     * GALILEO_API_URL
@@ -31,7 +32,9 @@ def configure() -> None:
     updated_config = dataquality.core._config.set_config()
     for k, v in updated_config.dict().items():
         config.__setattr__(k, v)
+    config.token = None
     config.update_file_config()
+    login()
 
 
 __all__ = [
