@@ -1,6 +1,6 @@
 import os
 import shutil
-from typing import Any, Generator
+from typing import Any, Callable, Dict, Generator
 from uuid import uuid4
 
 import pytest
@@ -9,10 +9,14 @@ from vaex.dataframe import DataFrame
 from dataquality import config
 from dataquality.clients import objectstore
 from dataquality.loggers import BaseGalileoLogger
+from dataquality.schemas.task_type import TaskType
 
 config.current_project_id = uuid4()
 config.current_run_id = uuid4()
 
+DEFAULT_API_URL = os.environ["GALILEO_API_URL"]
+DEFAULT_MINIO_URL = os.environ["GALILEO_MINIO_URL"]
+
 LOCATION = (
     f"{BaseGalileoLogger.LOG_FILE_DIR}/{config.current_project_id}"
     f"/{config.current_run_id}"
@@ -35,6 +39,27 @@ def cleanup_after_use() -> Generator:
         shutil.rmtree(LOCATION)
 
 
+@pytest.fixture()
+def set_test_config(
+    default_token: str = "sometoken",
+    default_task_type: TaskType = TaskType.text_classification,
+    default_api_url: str = DEFAULT_API_URL,
+    default_minio_url: str = DEFAULT_MINIO_URL,
+) -> Callable:
+    config.token = default_token
+    config.task_type = default_task_type
+    config.api_url = default_api_url
+    config.minio_url = default_minio_url
+
+    def curry(**kwargs: Dict[str, Any]) -> None:
+        # Override test config with custom value by currying
+        for k, v in kwargs.items():
+            if k in config.dict():
+                config.__setattr__(k, v)
+
+    return curry
+
+
 def patch_object_upload(self: Any, df: DataFrame, object_name: str) -> None:
     """
     A patch for the object_store.create_project_run_object_from_df so we don't have to
