@@ -1,3 +1,6 @@
+from typing import Callable
+
+import dataquality
 from dataquality.loggers import BaseGalileoLogger
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
 from dataquality.loggers.model_logger import BaseGalileoModelLogger
@@ -21,3 +24,14 @@ def test_attribute_subsets() -> None:
     )
     all_sub_attrs = data_logger_attrs.union(model_logger_attrs)
     assert all_attrs.issuperset(all_sub_attrs)
+
+
+def test_int_labels(set_test_config: Callable) -> None:
+    dataquality.set_labels_for_run(labels=[1, 2, 3, 4, 5])  # type: ignore
+    assert dataquality.get_data_logger().logger_config.labels == [
+        "1",
+        "2",
+        "3",
+        "4",
+        "5",
+    ]
